.. _swh-scanner:

Software Heritage - Code Scanner
================================

Source code scanner using the
`Software Heritage <https://www.softwareheritage.org/>`_
`archive <https://archive.softwareheritage.org/>`_
as knowledge base.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   cli
   /apidoc/swh.scanner
